Module errors

Module errors 

Error codes returned by the Steganography Online Codec Web API.

Constants

IMAGE_MALFORMED
Image file is malformed.
IMAGE_TOO_BIG
Image file is too big.
INVALID_IMAGE_FORMAT
Image file format is not supported.
INVALID_INPUT
Invalid input file or file does not exist.
INVALID_LICENSE
License key is invalid or expired.
INVALID_PASSWORD
Invalid password.
LIMIT_MESSAGE
Provided message is too long for the current license tier.
LIMIT_PASSWORD
Provided password is too long for the current license tier.
MESSAGE_TOO_LONG
Message is too long for the selected image file.
OUTPUT_FILE
Error while writing output file.
SUCCESS
Success.
UNKNOWN
Unknown error.
WEBAPI_CONNECTION
Cannot connect to the Web API interface (network error).