Error codes returned by the Steganography Online Codec Web API.
Constants
- IMAGE_
MALFORMED - Image file is malformed.
- IMAGE_
TOO_ BIG - Image file is too big.
- INVALID_
IMAGE_ FORMAT - Image file format is not supported.
- INVALID_
INPUT - Invalid input file or file does not exist.
- INVALID_
LICENSE - License key is invalid or expired.
- INVALID_
PASSWORD - Invalid password.
- LIMIT_
MESSAGE - Provided message is too long for the current license tier.
- LIMIT_
PASSWORD - Provided password is too long for the current license tier.
- MESSAGE_
TOO_ LONG - Message is too long for the selected image file.
- OUTPUT_
FILE - Error while writing output file.
- SUCCESS
- Success.
- UNKNOWN
- Unknown error.
- WEBAPI_
CONNECTION - Cannot connect to the Web API interface (network error).